@@ -128,13 +128,6 @@ TextDialog.prototype.show =  function(textDataIn) {
     this.sourceEdit = this.dialog.findChild("Source");
     this.tabWidget = this.dialog.findChild("TabWidget");
 
-    // brighter background of text area in dark mode:
-    if (RSettings.hasDarkGuiBackground()) {
-        var p = this.textEdit.palette;
-        p.setColor(QPalette.Active, QPalette.Base, new QColor(Qt.gray));
-        this.textEdit.palette = p;
-    }
-
     // main font combo box:
     var comboMainFont = this.dialog.findChild("MainFont");
     var comboFont = this.dialog.findChild("Font");
@@ -256,6 +249,7 @@ TextDialog.prototype.show =  function(textDataIn) {
         checkMainBold.checked = textDataIn.isBold();
         checkMainItalic.checked = textDataIn.isItalic();
         editMainHeight.setValue(textDataIn.getTextHeight());
+
         this.sourceEdit.setPlainText(textDataIn.getEscapedText());
         this.updateRichText(true);
         //qDebug("this.sourceEdit:", this.sourceEdit.plainText);
@@ -423,7 +417,7 @@ TextDialog.prototype.show =  function(textDataIn) {
         this.updateSource(true);
     }
 
-    // analize dialog input:
+    // analyze dialog input:
     var textDataOut;
     if (isNull(textDataIn)) {
         if (this.mode === TextDialog.Mode.Attribute) {
@@ -617,7 +611,10 @@ TextDialog.prototype.getMainFont = function() {
     var font = comboMainFont.currentFont;
 
     var editMainHeight = this.dialog.findChild("MainHeight");
-    font.setPointSizeF(editMainHeight.getValue());
+    var h = editMainHeight.getValue();
+    if (isNumber(h) && h>0.0) {
+        font.setPointSizeF(h);
+    }
 
     var checkMainBold = this.dialog.findChild("MainBold");
     font.setBold(checkMainBold.checked);
@@ -634,7 +631,12 @@ TextDialog.prototype.getMainFont = function() {
  */
 TextDialog.prototype.mainFontChanged = function() {
     var font = this.getMainFont();
-    this.fontHeightFactor = 14.0 / font.pointSizeF();
+    if (font.pointSizeF()>RS.PointTolerance) {
+        this.fontHeightFactor = RSettings.getDoubleValue("Text/PreviewFontSize", 14.0) / font.pointSizeF();
+    }
+    else {
+        this.fontHeightFactor = 10.0;
+    }
 
     if (this.tabWidget.currentIndex===1) {
         this.updateRichText(true);
@@ -713,17 +715,23 @@ TextDialog.prototype.fixHtml = function(html) {
         if(!e.isNull()) {
             if (e.tagName().toLowerCase()==="body") {
                 var qcol = this.initialColor.toCompat();
-                e.setAttribute("style",
-                               ("font-family:'%1';" +
-                               "font-size:%2pt;" +
-                               "font-weight:%3;" +
-                               "font-style:%4;" +
-                               "color:%5;")
-                               .arg(font.family())
-                               .arg(font.pointSizeF() * this.fontHeightFactor)
-                               .arg(font.weight()<=QFont.Normal ? "normal" : "bold")
-                               .arg(font.italic() ? "italic" : "normal")
-                               .arg(qcol.name()));
+                var bodyStyle = ("font-family:'%1';" +
+                        "font-size:%2pt;" +
+                        "font-weight:%3;" +
+                        "font-style:%4;" +
+                        "color:%5;")
+                        .arg(font.family())
+                        .arg(font.pointSizeF() * this.fontHeightFactor)
+                        .arg(font.weight()<=QFont.Normal ? "normal" : "bold")
+                        .arg(font.italic() ? "italic" : "normal")
+                        .arg(qcol.name());
+
+                // brighter background of text area in macOS dark mode:
+                if (RSettings.hasDarkGuiBackground() && RS.getSystemId()==="osx") {
+                    bodyStyle += "background-color:#dddddd;";
+                }
+
+                e.setAttribute("style", bodyStyle);
             }
         }
         n = n.nextSibling();
@@ -810,7 +818,9 @@ TextDialog.prototype.textSuperscript = function() {
  */
 TextDialog.prototype.textFamily = function(f) {
     var fmt = new QTextCharFormat();
-    fmt.setFontFamily(f);
+    // Qt 5.13, 5.14, 5.15 bug: appends the font as fall-back instead of setting the font:
+    //fmt.setFontFamily(f);
+    fmt.setFontFamilies([f]);
     this.mergeFormatOnWordOrSelection(fmt);
 };
 
@@ -1016,6 +1026,9 @@ TextDialog.prototype.updateRichText = function(force) {
         var richText = RTextBasedData.toRichText(source, this.getMainFont(), this.fontHeightFactor);
         //richText = richText.replace("<html>", "<html xmlns='http://www.w3.org/1999/xhtml' xml:space='preserve'>");
         //qDebug("richText: \n\n", richText, "\n\n");
+
+        // TODO: preserve tabs (img with arrow?)
+
         this.textEdit.setHtml(richText);
         //qDebug("HTML from text edit: \n\n", this.textEdit.html, "\n\n");
         this.getSourceDocument().modified = false;
